@@ -1,37 +1,37 @@
-#coding: utf-8
 from datetime import datetime
-from fabric.api import run, env, cd
-from fab_deploy.utils import run_as, inside_virtualenv
+from fabric.api import run, env
+from fab_deploy.utils import run_as, inside_project
 
 @run_as('root')
 def restart_apache():
     run('/etc/init.d/apache2 restart')
 
+@inside_project
 def touch():
     """ Reloads source code by touching the wsgi file """
-    run('touch %s/hosting/generated/django.wsgi' % env.conf['SRC_DIR'])
+    run('touch hosting/generated/django.wsgi')
 
-@inside_virtualenv
+@inside_project
 def pip_install(what='active', options=''):
     """ Installs pip requirements listed in reqs/<file>.txt file. """
-    run('pip install %s -r %s/reqs/%s.txt' % (options, env.conf['SRC_DIR'], what))
+    run('pip install %s -r reqs/%s.txt' % (options, what))
     touch()
 
-@inside_virtualenv
+@inside_project
 def pip_update(what='active', options='', restart=True):
     """ Updates pip requirements listed in reqs/<file>.txt file. """
-    run('pip install %s -U -r %s/reqs/%s.txt' % (options, env.conf['SRC_DIR'], what))
+    run('pip install %s -U -r reqs/%s.txt' % (options, what))
     if restart:
         touch()
 
+@inside_project
 def mysqldump(dir='hosting/backups'):
     now = datetime.now().strftime("%Y.%m.%d-%H.%M")
     db = env.conf['DB_NAME']
     password = env.conf['DB_PASSWORD']
-    with cd(env.conf['SRC_DIR']):
-        run('mysqldump -uroot -p%s %s > %s/%s%s.sql' % (password, db, dir, db, now))
+    run('mysqldump -uroot -p%s %s > %s/%s%s.sql' % (password, db, dir, db, now))
 
+@inside_project
 def delete_pyc():
     """ Deletes *.pyc files from project source dir """
-    with cd(env.conf['SRC_DIR']):
-        run("find . -name '*.pyc' -delete")
+    run("find . -name '*.pyc' -delete")
