@@ -1,16 +1,12 @@
 #coding: utf-8
 from __future__ import with_statement
-from fabric.api import env, cd, local, run, settings
+from fabric.api import run, settings
 from fab_deploy.commands import mysqldump
-from fab_deploy.utils import inside_virtualenv
+from fab_deploy.utils import inside_project
 
-@inside_virtualenv
-def manage(command, on_server=True):
-    if on_server:
-        with cd(env.conf['SRC_DIR']):
-            run('python ./manage.py '+ command)
-    else:
-        local('./manage.py ' + command)
+@inside_project
+def manage(command):
+    run('python ./manage.py '+ command)
 
 def migrate(params='', do_backup=True):
     if do_backup:
@@ -24,11 +20,10 @@ def compress(params=''):
     with settings(warn_only=True):
         manage('synccompress %s' % params)
 
-@inside_virtualenv
+@inside_project
 def test(what=''):
     with settings(warn_only=True):
-        with cd(env.conf['SRC_DIR']):
-            run('./runtests.sh ' + what)
+        run('./runtests.sh ' + what)
 
 def coverage():
     pass
