@@ -1,5 +1,5 @@
 from functools import wraps
-from fabric.context_managers import prefix
+from fabric.context_managers import prefix, cd
 from fabric.contrib.files import upload_template
 from fabric.api import env
 
@@ -71,3 +71,21 @@ def inside_virtualenv(func):
         with virtualenv():
             return func(*args, **kwargs)
     return inner
+
+def inside_project(func):
+    """
+    Decorator. Use it to perform actions inside project dir with
+    virtualenv activated:
+
+        @inside_project
+        def my_command():
+            # the current dir is a project source dir and
+            # virtualenv is activated
+
+    """
+    @wraps(func)
+    def inner(*args, **kwargs):
+        with cd(env.conf['SRC_DIR']):
+            with virtualenv():
+                return func(*args, **kwargs)
+    return inner
